#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axes_2 import axes
from .main import main
from .scale_3 import scale
from .text import text
from .video import video
from .xy import xy
from .logo import logo
from .ruler_1 import ruler
from .logo_color import logo_color
from .aspect_ratio import aspect_ratio
class windows(Group):
    """
    'windows' child.
    """

    fluent_name = "windows"

    child_names = \
        ['axes', 'main', 'scale', 'text', 'video', 'xy', 'logo', 'ruler',
         'logo_color']

    axes: axes = axes
    """
    axes child of windows.
    """
    main: main = main
    """
    main child of windows.
    """
    scale: scale = scale
    """
    scale child of windows.
    """
    text: text = text
    """
    text child of windows.
    """
    video: video = video
    """
    video child of windows.
    """
    xy: xy = xy
    """
    xy child of windows.
    """
    logo: logo = logo
    """
    logo child of windows.
    """
    ruler: ruler = ruler
    """
    ruler child of windows.
    """
    logo_color: logo_color = logo_color
    """
    logo_color child of windows.
    """
    command_names = \
        ['aspect_ratio']

    aspect_ratio: aspect_ratio = aspect_ratio
    """
    aspect_ratio command of windows.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class scalar_update_function(String):
    """
    Specify the name of the DPM scalar update function.
    """

    fluent_name = "scalar-update-function"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .default import default
from .reverse import reverse
class curve_length(Group):
    """
    'curve_length' child.
    """

    fluent_name = "curve-length"

    child_names = \
        ['option', 'default', 'reverse']

    option: option = option
    """
    option child of curve_length.
    """
    default: default = default
    """
    default child of curve_length.
    """
    reverse: reverse = reverse
    """
    reverse child of curve_length.
    """



"""Logging module.

This module supplies a general framework for logging in PyFluent.
"""

import logging
import os
from pathlib import Path
import tempfile
from typing import Any


class Logger:
    """Logger class.

    Methods
    -------
    set_level(level)
        Set the logging level.
    enable_logging_to_stdout()
        Enable logging to stdout.
    disable_logging_to_stdout()
        Disable logging to stdout.
    enable_logging_to_file(filepath)
        Enable logging to a file.
    disable_logging_to_file()
        Disable logging to a file.
    """

    def __init__(self, level: Any = logging.ERROR):
        self.logger = logging.getLogger()
        self.stream_handler = None
        self.file_handler = None
        self.log_filepath = None
        self.formatter = logging.Formatter(
            "%(asctime)s %(name)-12s %(levelname)-8s %(message)s"
        )
        self.enable_logging_to_stdout()
        self.logger.setLevel(level)

        # Writing logging methods.
        self.debug = self.logger.debug
        self.info = self.logger.info
        self.warning = self.logger.warning
        self.error = self.logger.error
        self.critical = self.logger.critical
        self.log = self.logger.log

    def set_level(self, level: Any) -> None:
        """Set the logging level.

        Parameters
        ----------
        level : Any
            Any of the logging levels in string or enum format. The options
            are ``CRITICAL``, ``ERROR``, ``WARNING``, ``INFO``, and ``DEBUG``.)
        """
        self.logger.setLevel(level)

    def _get_default_log_filepath(self):
        fd, filepath = tempfile.mkstemp(
            suffix=f"-{os.getpid()}.txt",
            prefix="pyfluent-",
            dir=str(Path.cwd()),
        )
        os.close(fd)
        return Path(filepath)

    def enable_logging_to_stdout(self) -> None:
        """Enable logging to stdout."""
        if self.stream_handler is None:
            self.stream_handler = logging.StreamHandler()
            self.stream_handler.setFormatter(self.formatter)
        self.logger.addHandler(self.stream_handler)

    def disable_logging_to_stdout(self) -> None:
        """Disable logging to stdout."""
        self.logger.removeHandler(self.stream_handler)

    def enable_logging_to_file(self, filepath: str = None) -> None:
        """Enable logging to a file.

        Parameters
        ----------
        filepath : str, optional
            Path to the file. If a file is not specified, a default path
            is chosen.
        """
        self.logger.removeHandler(self.file_handler)
        if not filepath and not self.log_filepath:
            self.log_filepath = self._get_default_log_filepath()
        elif filepath:
            self.log_filepath = Path(filepath)
        self.file_handler = logging.FileHandler(self.log_filepath)
        self.file_handler.setFormatter(self.formatter)
        self.logger.addHandler(self.file_handler)

    def disable_logging_to_file(self) -> None:
        """Disable logging to a file."""
        self.logger.removeHandler(self.file_handler)

    def getEffectiveLevel(self) -> int:
        return self.logger.getEffectiveLevel()

    def getLevelName(self) -> str:
        return logging.getLevelName(self.getEffectiveLevel())


LOG = Logger()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .picture_options import picture_options
from .camera import camera
from .display_states import display_states
from .save_picture import save_picture
from .auto_scale_1 import auto_scale
from .reset_to_default_view import reset_to_default_view
from .delete_view import delete_view
from .last_view import last_view
from .next_view import next_view
from .restore_view import restore_view
from .read_views import read_views
from .save_view import save_view
from .write_views import write_views
class views(Group):
    """
    'views' child.
    """

    fluent_name = "views"

    child_names = \
        ['picture_options', 'camera', 'display_states']

    picture_options: picture_options = picture_options
    """
    picture_options child of views.
    """
    camera: camera = camera
    """
    camera child of views.
    """
    display_states: display_states = display_states
    """
    display_states child of views.
    """
    command_names = \
        ['save_picture', 'auto_scale', 'reset_to_default_view', 'delete_view',
         'last_view', 'next_view', 'restore_view', 'read_views', 'save_view',
         'write_views']

    save_picture: save_picture = save_picture
    """
    save_picture command of views.
    """
    auto_scale: auto_scale = auto_scale
    """
    auto_scale command of views.
    """
    reset_to_default_view: reset_to_default_view = reset_to_default_view
    """
    reset_to_default_view command of views.
    """
    delete_view: delete_view = delete_view
    """
    delete_view command of views.
    """
    last_view: last_view = last_view
    """
    last_view command of views.
    """
    next_view: next_view = next_view
    """
    next_view command of views.
    """
    restore_view: restore_view = restore_view
    """
    restore_view command of views.
    """
    read_views: read_views = read_views
    """
    read_views command of views.
    """
    save_view: save_view = save_view
    """
    save_view command of views.
    """
    write_views: write_views = write_views
    """
    write_views command of views.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .wave_list_child import wave_list_child

class wave_list(ListObject[wave_list_child]):
    """
    'wave_list' child.
    """

    fluent_name = "wave-list"

    child_object_type: wave_list_child = wave_list_child
    """
    child_object_type of wave_list.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .iter_count_4 import iter_count
from .time_steps_count import time_steps_count
from .fluid_time_step_count import fluid_time_step_count
from .iter_per_time_step_count import iter_per_time_step_count
class iterate(Command):
    """
    Iteration the multidomain conjugate heat transfer.
    
    Parameters
    ----------
        iter_count : int
            'iter_count' child.
        time_steps_count : int
            'time_steps_count' child.
        fluid_time_step_count : int
            'fluid_time_step_count' child.
        iter_per_time_step_count : int
            'iter_per_time_step_count' child.
    
    """

    fluent_name = "iterate"

    argument_names = \
        ['iter_count', 'time_steps_count', 'fluid_time_step_count',
         'iter_per_time_step_count']

    iter_count: iter_count = iter_count
    """
    iter_count argument of iterate.
    """
    time_steps_count: time_steps_count = time_steps_count
    """
    time_steps_count argument of iterate.
    """
    fluid_time_step_count: fluid_time_step_count = fluid_time_step_count
    """
    fluid_time_step_count argument of iterate.
    """
    iter_per_time_step_count: iter_per_time_step_count = iter_per_time_step_count
    """
    iter_per_time_step_count argument of iterate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .particle_type import particle_type
from .material import material
from .reference_frame import reference_frame
from .number_of_streams import number_of_streams
from .injection_type import injection_type
from .interaction_1 import interaction
from .parcel_method import parcel_method
from .particle_reinjector import particle_reinjector
from .physical_models import physical_models
from .initial_props import initial_props
class injections_child(Group):
    """
    'child_object_type' of injections.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['particle_type', 'material', 'reference_frame', 'number_of_streams',
         'injection_type', 'interaction', 'parcel_method',
         'particle_reinjector', 'physical_models', 'initial_props']

    particle_type: particle_type = particle_type
    """
    particle_type child of injections_child.
    """
    material: material = material
    """
    material child of injections_child.
    """
    reference_frame: reference_frame = reference_frame
    """
    reference_frame child of injections_child.
    """
    number_of_streams: number_of_streams = number_of_streams
    """
    number_of_streams child of injections_child.
    """
    injection_type: injection_type = injection_type
    """
    injection_type child of injections_child.
    """
    interaction: interaction = interaction
    """
    interaction child of injections_child.
    """
    parcel_method: parcel_method = parcel_method
    """
    parcel_method child of injections_child.
    """
    particle_reinjector: particle_reinjector = particle_reinjector
    """
    particle_reinjector child of injections_child.
    """
    physical_models: physical_models = physical_models
    """
    physical_models child of injections_child.
    """
    initial_props: initial_props = initial_props
    """
    initial_props child of injections_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .expression import expression
from .polynomial import polynomial
from .user_defined_function import user_defined_function
from .anisotropic import anisotropic
from .orthotropic import orthotropic
from .cyl_orthotropic import cyl_orthotropic
class uds_diffusivities_child(Group):
    """
    'child_object_type' of uds_diffusivities.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['option', 'value', 'expression', 'polynomial',
         'user_defined_function', 'anisotropic', 'orthotropic',
         'cyl_orthotropic']

    option: option = option
    """
    option child of uds_diffusivities_child.
    """
    value: value = value
    """
    value child of uds_diffusivities_child.
    """
    expression: expression = expression
    """
    expression child of uds_diffusivities_child.
    """
    polynomial: polynomial = polynomial
    """
    polynomial child of uds_diffusivities_child.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of uds_diffusivities_child.
    """
    anisotropic: anisotropic = anisotropic
    """
    anisotropic child of uds_diffusivities_child.
    """
    orthotropic: orthotropic = orthotropic
    """
    orthotropic child of uds_diffusivities_child.
    """
    cyl_orthotropic: cyl_orthotropic = cyl_orthotropic
    """
    cyl_orthotropic child of uds_diffusivities_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .user_specified_species import user_specified_species
from .species_1 import species
class species_setting(Group):
    """
    Enter the species settings menu.
    """

    fluent_name = "species-setting"

    child_names = \
        ['user_specified_species', 'species']

    user_specified_species: user_specified_species = user_specified_species
    """
    user_specified_species child of species_setting.
    """
    species: species = species
    """
    species child of species_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .include_pop_in_fsi_force import include_pop_in_fsi_force
from .steady_2way_fsi import steady_2way_fsi
from .include_viscous_fsi_force import include_viscous_fsi_force
from .explicit_fsi_force import explicit_fsi_force
from .starting_t_re_initialization import starting_t_re_initialization
class expert(Group):
    """
    Enter the structure expert menu.
    """

    fluent_name = "expert"

    child_names = \
        ['include_pop_in_fsi_force', 'steady_2way_fsi',
         'include_viscous_fsi_force', 'explicit_fsi_force',
         'starting_t_re_initialization']

    include_pop_in_fsi_force: include_pop_in_fsi_force = include_pop_in_fsi_force
    """
    include_pop_in_fsi_force child of expert.
    """
    steady_2way_fsi: steady_2way_fsi = steady_2way_fsi
    """
    steady_2way_fsi child of expert.
    """
    include_viscous_fsi_force: include_viscous_fsi_force = include_viscous_fsi_force
    """
    include_viscous_fsi_force child of expert.
    """
    explicit_fsi_force: explicit_fsi_force = explicit_fsi_force
    """
    explicit_fsi_force child of expert.
    """
    starting_t_re_initialization: starting_t_re_initialization = starting_t_re_initialization
    """
    starting_t_re_initialization child of expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .new import new
from .open import open
from .save import save
from .save_as import save_as
from .save_as_copy import save_as_copy
from .archive import archive
class parametric_project(Group):
    """
    'parametric_project' child.
    """

    fluent_name = "parametric-project"

    command_names = \
        ['new', 'open', 'save', 'save_as', 'save_as_copy', 'archive']

    new: new = new
    """
    new command of parametric_project.
    """
    open: open = open
    """
    open command of parametric_project.
    """
    save: save = save
    """
    save command of parametric_project.
    """
    save_as: save_as = save_as
    """
    save_as command of parametric_project.
    """
    save_as_copy: save_as_copy = save_as_copy
    """
    save_as_copy command of parametric_project.
    """
    archive: archive = archive
    """
    archive command of parametric_project.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class convert_all_solid_mrf_to_solid_motion(Command):
    """
    Change all solid zones motion specification from MRF to solid motion.
    """

    fluent_name = "convert-all-solid-mrf-to-solid-motion"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .piecewise_linear import piecewise_linear
from .piecewise_polynomial import piecewise_polynomial
from .polynomial import polynomial
from .user_defined_function import user_defined_function
class diffusivity(Group):
    """
    'diffusivity' child.
    """

    fluent_name = "diffusivity"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'user_defined_function']

    option: option = option
    """
    option child of diffusivity.
    """
    value: value = value
    """
    value child of diffusivity.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of diffusivity.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of diffusivity.
    """
    polynomial: polynomial = polynomial
    """
    polynomial child of diffusivity.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .outflow_child import outflow_child

class outflow(NamedObject[outflow_child], _NonCreatableNamedObjectMixin[outflow_child]):
    """
    'outflow' child.
    """

    fluent_name = "outflow"

    child_object_type: outflow_child = outflow_child
    """
    child_object_type of outflow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .usage import usage
from .reset_1 import reset
class timer(Group):
    """
    'timer' child.
    """

    fluent_name = "timer"

    command_names = \
        ['usage', 'reset']

    usage: usage = usage
    """
    usage command of timer.
    """
    reset: reset = reset
    """
    reset command of timer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class pseudo_time_stabilization(Boolean):
    """
    Pseudo-Time Momentum stabilization and False Time Step Linearization methods for VOF.
    """

    fluent_name = "pseudo-time-stabilization?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .surface_id_val import surface_id_val
from .min_feature_size import min_feature_size
from .proj_plane_norm_comp import proj_plane_norm_comp
class projected_surface_area(Command):
    """
    Print total area of the projection of a group of surfaces to a plane.
    
    Parameters
    ----------
        surface_id_val : typing.List[int]
            'surface_id_val' child.
        min_feature_size : real
            'min_feature_size' child.
        proj_plane_norm_comp : typing.Tuple[real, real, real]
            'proj_plane_norm_comp' child.
    
    """

    fluent_name = "projected-surface-area"

    argument_names = \
        ['surface_id_val', 'min_feature_size', 'proj_plane_norm_comp']

    surface_id_val: surface_id_val = surface_id_val
    """
    surface_id_val argument of projected_surface_area.
    """
    min_feature_size: min_feature_size = min_feature_size
    """
    min_feature_size argument of projected_surface_area.
    """
    proj_plane_norm_comp: proj_plane_norm_comp = proj_plane_norm_comp
    """
    proj_plane_norm_comp argument of projected_surface_area.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .zone_id import zone_id
class mrf_to_sliding_mesh(Command):
    """
    Change motion specification from MRF to moving mesh.
    
    Parameters
    ----------
        zone_id : int
            'zone_id' child.
    
    """

    fluent_name = "mrf-to-sliding-mesh"

    argument_names = \
        ['zone_id']

    zone_id: zone_id = zone_id
    """
    zone_id argument of mrf_to_sliding_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multi_grid import multi_grid
from .multi_stage import multi_stage
from .expert_1 import expert
from .fast_transient_settings import fast_transient_settings
from .relaxation_method import relaxation_method
from .correction_tolerance import correction_tolerance
class advanced(Group):
    """
    'advanced' child.
    """

    fluent_name = "advanced"

    child_names = \
        ['multi_grid', 'multi_stage', 'expert', 'fast_transient_settings',
         'relaxation_method', 'correction_tolerance']

    multi_grid: multi_grid = multi_grid
    """
    multi_grid child of advanced.
    """
    multi_stage: multi_stage = multi_stage
    """
    multi_stage child of advanced.
    """
    expert: expert = expert
    """
    expert child of advanced.
    """
    fast_transient_settings: fast_transient_settings = fast_transient_settings
    """
    fast_transient_settings child of advanced.
    """
    relaxation_method: relaxation_method = relaxation_method
    """
    relaxation_method child of advanced.
    """
    correction_tolerance: correction_tolerance = correction_tolerance
    """
    correction_tolerance child of advanced.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_12 import option
from .iterations import iterations
from .time_steps import time_steps
class frequency(Group):
    """
    Define the frequency at which cells in the register are automatically marked for poor mesh numerics treatment.
    """

    fluent_name = "frequency"

    child_names = \
        ['option', 'iterations', 'time_steps']

    option: option = option
    """
    option child of frequency.
    """
    iterations: iterations = iterations
    """
    iterations child of frequency.
    """
    time_steps: time_steps = time_steps
    """
    time_steps child of frequency.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .model_tip_loss import model_tip_loss
from .tip_loss_limit import tip_loss_limit
from .prandtl_tuning_coefficient import prandtl_tuning_coefficient
class tip_loss(Group):
    """
    Menu to define the rotor tip loss model.
    
     - method  : define the method to model rotor tip loss, quadratic-tip-loss, prandtl-tip-loss
     - tip-loss-limit : tip-loss-limit, 
     - prandtl-tuning-coefficient: prandtl-tuning-coefficient, 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "tip-loss"

    child_names = \
        ['model_tip_loss', 'tip_loss_limit', 'prandtl_tuning_coefficient']

    model_tip_loss: model_tip_loss = model_tip_loss
    """
    model_tip_loss child of tip_loss.
    """
    tip_loss_limit: tip_loss_limit = tip_loss_limit
    """
    tip_loss_limit child of tip_loss.
    """
    prandtl_tuning_coefficient: prandtl_tuning_coefficient = prandtl_tuning_coefficient
    """
    prandtl_tuning_coefficient child of tip_loss.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .solid_child_1 import solid_child

class solid(NamedObject[solid_child], _NonCreatableNamedObjectMixin[solid_child]):
    """
    'solid' child.
    """

    fluent_name = "solid"

    child_object_type: solid_child = solid_child
    """
    child_object_type of solid.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class control_time_step_size_variation(Boolean):
    """
    Enter Control time step size variation.
    """

    fluent_name = "control-time-step-size-variation?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class create_all_shell_threads(Command):
    """
    Mark all finite thickness wall for shell creation. Shell zones will be created at the start of iterations.
    """

    fluent_name = "create-all-shell-threads"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .thread_id_list import thread_id_list
from .domain import domain
from .cell_function import cell_function
from .current_domain import current_domain
from .write_to_file import write_to_file
from .file_name_1 import file_name
from .append_data import append_data
from .overwrite import overwrite
class volume_integrals(Command):
    """
    'volume_integrals' command.
    
    Parameters
    ----------
        report_type : str
            'report_type' child.
        thread_id_list : typing.List[str]
            'thread_id_list' child.
        domain : str
            'domain' child.
        cell_function : str
            'cell_function' child.
        current_domain : str
            'current_domain' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "volume-integrals"

    argument_names = \
        ['report_type', 'thread_id_list', 'domain', 'cell_function',
         'current_domain', 'write_to_file', 'file_name', 'append_data',
         'overwrite']

    report_type: report_type = report_type
    """
    report_type argument of volume_integrals.
    """
    thread_id_list: thread_id_list = thread_id_list
    """
    thread_id_list argument of volume_integrals.
    """
    domain: domain = domain
    """
    domain argument of volume_integrals.
    """
    cell_function: cell_function = cell_function
    """
    cell_function argument of volume_integrals.
    """
    current_domain: current_domain = current_domain
    """
    current_domain argument of volume_integrals.
    """
    write_to_file: write_to_file = write_to_file
    """
    write_to_file argument of volume_integrals.
    """
    file_name: file_name = file_name
    """
    file_name argument of volume_integrals.
    """
    append_data: append_data = append_data
    """
    append_data argument of volume_integrals.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of volume_integrals.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .ni import ni
from .nj import nj
from .nk import nk
from .xe import xe
from .len import len
class beach_dir_list_child(Group):
    """
    'child_object_type' of beach_dir_list.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['ni', 'nj', 'nk', 'xe', 'len']

    ni: ni = ni
    """
    ni child of beach_dir_list_child.
    """
    nj: nj = nj
    """
    nj child of beach_dir_list_child.
    """
    nk: nk = nk
    """
    nk child of beach_dir_list_child.
    """
    xe: xe = xe
    """
    xe child of beach_dir_list_child.
    """
    len: len = len
    """
    len child of beach_dir_list_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .flow_rate import flow_rate
from .flow_rate_2 import flow_rate_2
from .total_flow_rate import total_flow_rate
from .scale_by_area import scale_by_area
class flow_rate(Group):
    """
    'flow_rate' child.
    """

    fluent_name = "flow-rate"

    child_names = \
        ['flow_rate', 'flow_rate_2', 'total_flow_rate', 'scale_by_area']

    flow_rate: flow_rate = flow_rate
    """
    flow_rate child of flow_rate.
    """
    flow_rate_2: flow_rate_2 = flow_rate_2
    """
    flow_rate_2 child of flow_rate.
    """
    total_flow_rate: total_flow_rate = total_flow_rate
    """
    total_flow_rate child of flow_rate.
    """
    scale_by_area: scale_by_area = scale_by_area
    """
    scale_by_area child of flow_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .general import general
from .models_1 import models
from .materials import materials
from .cell_zone_conditions import cell_zone_conditions
from .boundary_conditions import boundary_conditions
from .reference_values import reference_values
from .named_expressions import named_expressions
class setup(Group):
    """
    'setup' child.
    """

    fluent_name = "setup"

    child_names = \
        ['general', 'models', 'materials', 'cell_zone_conditions',
         'boundary_conditions', 'reference_values', 'named_expressions']

    general: general = general
    """
    general child of setup.
    """
    models: models = models
    """
    models child of setup.
    """
    materials: materials = materials
    """
    materials child of setup.
    """
    cell_zone_conditions: cell_zone_conditions = cell_zone_conditions
    """
    cell_zone_conditions child of setup.
    """
    boundary_conditions: boundary_conditions = boundary_conditions
    """
    boundary_conditions child of setup.
    """
    reference_values: reference_values = reference_values
    """
    reference_values child of setup.
    """
    named_expressions: named_expressions = named_expressions
    """
    named_expressions child of setup.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .geometry_3 import geometry
from .physics import physics
from .retain_instantaneous_values import retain_instantaneous_values
from .scaled import scaled
from .average_over import average_over
from .per_zone import per_zone
from .thread_names import thread_names
from .thread_ids import thread_ids
from .old_props import old_props
from .reference_frame import reference_frame
from .force_vector import force_vector
class force_child(Group):
    """
    'child_object_type' of force.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'geometry', 'physics', 'retain_instantaneous_values',
         'scaled', 'average_over', 'per_zone', 'thread_names', 'thread_ids',
         'old_props', 'reference_frame', 'force_vector']

    report_type: report_type = report_type
    """
    report_type child of force_child.
    """
    geometry: geometry = geometry
    """
    geometry child of force_child.
    """
    physics: physics = physics
    """
    physics child of force_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of force_child.
    """
    scaled: scaled = scaled
    """
    scaled child of force_child.
    """
    average_over: average_over = average_over
    """
    average_over child of force_child.
    """
    per_zone: per_zone = per_zone
    """
    per_zone child of force_child.
    """
    thread_names: thread_names = thread_names
    """
    thread_names child of force_child.
    """
    thread_ids: thread_ids = thread_ids
    """
    thread_ids child of force_child.
    """
    old_props: old_props = old_props
    """
    old_props child of force_child.
    """
    reference_frame: reference_frame = reference_frame
    """
    reference_frame child of force_child.
    """
    force_vector: force_vector = force_vector
    """
    force_vector child of force_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .background import background
from .color_by_type import color_by_type
from .foreground import foreground
from .by_type import by_type
from .by_surface import by_surface
from .far_field_faces import far_field_faces
from .inlet_faces import inlet_faces
from .interior_faces import interior_faces
from .internal_faces import internal_faces
from .outlet_faces import outlet_faces
from .overset_faces import overset_faces
from .periodic_faces import periodic_faces
from .rans_les_interface_faces import rans_les_interface_faces
from .symmetry_faces import symmetry_faces
from .axis_faces import axis_faces
from .free_surface_faces import free_surface_faces
from .traction_faces import traction_faces
from .wall_faces import wall_faces
from .interface_faces import interface_faces
from .surface_2 import surface
from .skip_label import skip_label
from .automatic_skip import automatic_skip
from .reset_colors import reset_colors
from .list_colors import list_colors
class colors(Group):
    """
    'colors' child.
    """

    fluent_name = "colors"

    child_names = \
        ['background', 'color_by_type', 'foreground', 'by_type', 'by_surface',
         'far_field_faces', 'inlet_faces', 'interior_faces', 'internal_faces',
         'outlet_faces', 'overset_faces', 'periodic_faces',
         'rans_les_interface_faces', 'symmetry_faces', 'axis_faces',
         'free_surface_faces', 'traction_faces', 'wall_faces',
         'interface_faces', 'surface', 'skip_label', 'automatic_skip']

    background: background = background
    """
    background child of colors.
    """
    color_by_type: color_by_type = color_by_type
    """
    color_by_type child of colors.
    """
    foreground: foreground = foreground
    """
    foreground child of colors.
    """
    by_type: by_type = by_type
    """
    by_type child of colors.
    """
    by_surface: by_surface = by_surface
    """
    by_surface child of colors.
    """
    far_field_faces: far_field_faces = far_field_faces
    """
    far_field_faces child of colors.
    """
    inlet_faces: inlet_faces = inlet_faces
    """
    inlet_faces child of colors.
    """
    interior_faces: interior_faces = interior_faces
    """
    interior_faces child of colors.
    """
    internal_faces: internal_faces = internal_faces
    """
    internal_faces child of colors.
    """
    outlet_faces: outlet_faces = outlet_faces
    """
    outlet_faces child of colors.
    """
    overset_faces: overset_faces = overset_faces
    """
    overset_faces child of colors.
    """
    periodic_faces: periodic_faces = periodic_faces
    """
    periodic_faces child of colors.
    """
    rans_les_interface_faces: rans_les_interface_faces = rans_les_interface_faces
    """
    rans_les_interface_faces child of colors.
    """
    symmetry_faces: symmetry_faces = symmetry_faces
    """
    symmetry_faces child of colors.
    """
    axis_faces: axis_faces = axis_faces
    """
    axis_faces child of colors.
    """
    free_surface_faces: free_surface_faces = free_surface_faces
    """
    free_surface_faces child of colors.
    """
    traction_faces: traction_faces = traction_faces
    """
    traction_faces child of colors.
    """
    wall_faces: wall_faces = wall_faces
    """
    wall_faces child of colors.
    """
    interface_faces: interface_faces = interface_faces
    """
    interface_faces child of colors.
    """
    surface: surface = surface
    """
    surface child of colors.
    """
    skip_label: skip_label = skip_label
    """
    skip_label child of colors.
    """
    automatic_skip: automatic_skip = automatic_skip
    """
    automatic_skip child of colors.
    """
    command_names = \
        ['reset_colors', 'list_colors']

    reset_colors: reset_colors = reset_colors
    """
    reset_colors command of colors.
    """
    list_colors: list_colors = list_colors
    """
    list_colors command of colors.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use_multi_physics import use_multi_physics
from .threshold import threshold
from .interval import interval
class physical_models(Group):
    """
    Use physical-models load balancing?.
    """

    fluent_name = "physical-models"

    child_names = \
        ['use_multi_physics', 'threshold', 'interval']

    use_multi_physics: use_multi_physics = use_multi_physics
    """
    use_multi_physics child of physical_models.
    """
    threshold: threshold = threshold
    """
    threshold child of physical_models.
    """
    interval: interval = interval
    """
    interval child of physical_models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .case_frequency import case_frequency
from .data_frequency import data_frequency
from .root_name import root_name
from .retain_most_recent_files import retain_most_recent_files
from .max_files import max_files
from .append_file_name_with import append_file_name_with
from .save_data_file_every import save_data_file_every
class auto_save(Group):
    """
    'auto_save' child.
    """

    fluent_name = "auto-save"

    child_names = \
        ['case_frequency', 'data_frequency', 'root_name',
         'retain_most_recent_files', 'max_files', 'append_file_name_with',
         'save_data_file_every']

    case_frequency: case_frequency = case_frequency
    """
    case_frequency child of auto_save.
    """
    data_frequency: data_frequency = data_frequency
    """
    data_frequency child of auto_save.
    """
    root_name: root_name = root_name
    """
    root_name child of auto_save.
    """
    retain_most_recent_files: retain_most_recent_files = retain_most_recent_files
    """
    retain_most_recent_files child of auto_save.
    """
    max_files: max_files = max_files
    """
    max_files child of auto_save.
    """
    append_file_name_with: append_file_name_with = append_file_name_with
    """
    append_file_name_with child of auto_save.
    """
    save_data_file_every: save_data_file_every = save_data_file_every
    """
    save_data_file_every child of auto_save.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .dynamic_stress import dynamic_stress
from .dynamic_energy_flux import dynamic_energy_flux
from .dynamic_scalar_flux import dynamic_scalar_flux
from .subgrid_dynamic_fvar import subgrid_dynamic_fvar
class les_model_options(Group):
    """
    'les_model_options' child.
    """

    fluent_name = "les-model-options"

    child_names = \
        ['dynamic_stress', 'dynamic_energy_flux', 'dynamic_scalar_flux',
         'subgrid_dynamic_fvar']

    dynamic_stress: dynamic_stress = dynamic_stress
    """
    dynamic_stress child of les_model_options.
    """
    dynamic_energy_flux: dynamic_energy_flux = dynamic_energy_flux
    """
    dynamic_energy_flux child of les_model_options.
    """
    dynamic_scalar_flux: dynamic_scalar_flux = dynamic_scalar_flux
    """
    dynamic_scalar_flux child of les_model_options.
    """
    subgrid_dynamic_fvar: subgrid_dynamic_fvar = subgrid_dynamic_fvar
    """
    subgrid_dynamic_fvar child of les_model_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .general_settings_1 import general_settings
from .turbulent_setting import turbulent_setting
from .species_setting import species_setting
class hybrid_init_options(Group):
    """
    Enter the settings for hybrid initialization method.
    """

    fluent_name = "hybrid-init-options"

    child_names = \
        ['general_settings', 'turbulent_setting', 'species_setting']

    general_settings: general_settings = general_settings
    """
    general_settings child of hybrid_init_options.
    """
    turbulent_setting: turbulent_setting = turbulent_setting
    """
    turbulent_setting child of hybrid_init_options.
    """
    species_setting: species_setting = species_setting
    """
    species_setting child of hybrid_init_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class turb_pk_compressible(Boolean):
    """
    Enable/disable turbulent production due to compressible divergence.
    """

    fluent_name = "turb-pk-compressible?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .geometry_3 import geometry
from .physics import physics
from .field import field
from .retain_instantaneous_values import retain_instantaneous_values
from .phase_25 import phase
from .average_over import average_over
from .per_zone import per_zone
from .old_props import old_props
from .zone_names import zone_names
from .expr_list import expr_list
from .zone_list import zone_list
class volume_child(Group):
    """
    'child_object_type' of volume.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'geometry', 'physics', 'field',
         'retain_instantaneous_values', 'phase', 'average_over', 'per_zone',
         'old_props', 'zone_names', 'expr_list', 'zone_list']

    report_type: report_type = report_type
    """
    report_type child of volume_child.
    """
    geometry: geometry = geometry
    """
    geometry child of volume_child.
    """
    physics: physics = physics
    """
    physics child of volume_child.
    """
    field: field = field
    """
    field child of volume_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of volume_child.
    """
    phase: phase = phase
    """
    phase child of volume_child.
    """
    average_over: average_over = average_over
    """
    average_over child of volume_child.
    """
    per_zone: per_zone = per_zone
    """
    per_zone child of volume_child.
    """
    old_props: old_props = old_props
    """
    old_props child of volume_child.
    """
    zone_names: zone_names = zone_names
    """
    zone_names child of volume_child.
    """
    expr_list: expr_list = expr_list
    """
    expr_list child of volume_child.
    """
    zone_list: zone_list = zone_list
    """
    zone_list child of volume_child.
    """



import os
from pathlib import Path

from ansys.fluent.core.services.transcript import TranscriptService
from ansys.fluent.core.streaming_services.streaming import StreamingService


class AppendToFile:
    def __init__(self, file_path: str):
        self.f = open(file_path, "a")

    def __call__(self, transcript):
        self.f.write(transcript)

    def __del__(self):
        self.f.close()


class Transcript(StreamingService):
    """Encapsulates a Fluent Transcript streaming service."""

    _writing_transcript_to_interpreter = False

    def __init__(self, channel, metadata):
        super().__init__(
            target=Transcript._process_streaming,
            streaming_service=TranscriptService(channel, metadata),
        )
        self.callback_ids = []

    def start(self, file_path: str = None, write_to_interpreter: bool = True) -> None:
        """Start streaming of Fluent transcript.

         Parameters
        ----------
        file_path: str, optional
            File path to write the transcript stream.
        write_to_interpreter: bool, optional
            Flag to print transcript on the screen or not
        """
        if not Transcript._writing_transcript_to_interpreter:
            if write_to_interpreter:
                self.callback_ids.append(self.register_callback(print))
                Transcript._writing_transcript_to_interpreter = True
        if file_path:
            if Path(file_path).exists():
                os.remove(file_path)
            append_to_file = AppendToFile(file_path)
            self.callback_ids.append(
                self.register_callback(append_to_file, keep_new_lines=True)
            )
        super().start()

    def stop(self) -> None:
        """Stop streaming of Fluent transcript."""
        for callback_id in self.callback_ids:
            self.unregister_callback(callback_id)
        super().stop()

    def _process_streaming(self, started_evt):
        """Performs processes on transcript depending on the callback
        functions."""
        responses = self._streaming_service.begin_streaming(started_evt)
        transcript = ""
        while True:
            try:
                response = next(responses)
                with self._lock:
                    self._streaming = True
                    transcript += response.transcript
                    if transcript[-1] == "\n":
                        for callback_map in self._service_callbacks.values():
                            if "keep_new_lines" in callback_map[-1].keys():
                                if callback_map[-1]["keep_new_lines"]:
                                    callback_map[0](transcript)
                                else:
                                    callback_map[0](transcript[0:-1])
                            else:
                                callback_map[0](transcript[0:-1])
                        transcript = ""
            except StopIteration:
                break



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mg_controls import mg_controls
from .amg_controls import amg_controls
from .fas_mg_controls import fas_mg_controls
from .amg_gpgpu_options import amg_gpgpu_options
class multi_grid(Group):
    """
    'multi_grid' child.
    """

    fluent_name = "multi-grid"

    child_names = \
        ['mg_controls', 'amg_controls', 'fas_mg_controls',
         'amg_gpgpu_options']

    mg_controls: mg_controls = mg_controls
    """
    mg_controls child of multi_grid.
    """
    amg_controls: amg_controls = amg_controls
    """
    amg_controls child of multi_grid.
    """
    fas_mg_controls: fas_mg_controls = fas_mg_controls
    """
    fas_mg_controls child of multi_grid.
    """
    amg_gpgpu_options: amg_gpgpu_options = amg_gpgpu_options
    """
    amg_gpgpu_options child of multi_grid.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class front_faces_transparent(String):
    """
    'front_faces_transparent' child.
    """

    fluent_name = "front-faces-transparent"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class reset_sources_at_timestep(Boolean):
    """
    Enable/disable flushing of DPM source terms at beginning of every time step.
    """

    fluent_name = "reset-sources-at-timestep?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sample_var import sample_var
from .enable_log import enable_log
class use_logarithmic(Command):
    """
    Switch on or off logarithmic scaling to be used for a specific variable in the data reduction.
    
    Parameters
    ----------
        sample_var : str
            'sample_var' child.
        enable_log : bool
            'enable_log' child.
    
    """

    fluent_name = "use-logarithmic?"

    argument_names = \
        ['sample_var', 'enable_log']

    sample_var: sample_var = sample_var
    """
    sample_var argument of use_logarithmic.
    """
    enable_log: enable_log = enable_log
    """
    enable_log argument of use_logarithmic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .write_summary_to_file import write_summary_to_file
from .file_name_1 import file_name
from .include_in_domains_particles import include_in_domains_particles
from .pick_injection import pick_injection
from .injection_1 import injection
class extended_summary(Command):
    """
    Print extended discrete phase summary report of particle fates, with options.
    
    Parameters
    ----------
        write_summary_to_file : bool
            'write_summary_to_file' child.
        file_name : str
            'file_name' child.
        include_in_domains_particles : bool
            'include_in_domains_particles' child.
        pick_injection : bool
            'pick_injection' child.
        injection : str
            'injection' child.
    
    """

    fluent_name = "extended-summary"

    argument_names = \
        ['write_summary_to_file', 'file_name', 'include_in_domains_particles',
         'pick_injection', 'injection']

    write_summary_to_file: write_summary_to_file = write_summary_to_file
    """
    write_summary_to_file argument of extended_summary.
    """
    file_name: file_name = file_name
    """
    file_name argument of extended_summary.
    """
    include_in_domains_particles: include_in_domains_particles = include_in_domains_particles
    """
    include_in_domains_particles argument of extended_summary.
    """
    pick_injection: pick_injection = pick_injection
    """
    pick_injection argument of extended_summary.
    """
    injection: injection = injection
    """
    injection argument of extended_summary.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .in_plane import in_plane
from .fixed_length import fixed_length
from .x_comp import x_comp
from .y_comp import y_comp
from .z_comp import z_comp
from .scale_head import scale_head
from .color import color
class vector_opt(Group):
    """
    'vector_opt' child.
    """

    fluent_name = "vector-opt"

    child_names = \
        ['in_plane', 'fixed_length', 'x_comp', 'y_comp', 'z_comp',
         'scale_head', 'color']

    in_plane: in_plane = in_plane
    """
    in_plane child of vector_opt.
    """
    fixed_length: fixed_length = fixed_length
    """
    fixed_length child of vector_opt.
    """
    x_comp: x_comp = x_comp
    """
    x_comp child of vector_opt.
    """
    y_comp: y_comp = y_comp
    """
    y_comp child of vector_opt.
    """
    z_comp: z_comp = z_comp
    """
    z_comp child of vector_opt.
    """
    scale_head: scale_head = scale_head
    """
    scale_head child of vector_opt.
    """
    color: color = color
    """
    color child of vector_opt.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .cross_section_multicomponent import cross_section_multicomponent
class collision_cross_section(Group):
    """
    'collision_cross_section' child.
    """

    fluent_name = "collision-cross-section"

    child_names = \
        ['option', 'cross_section_multicomponent']

    option: option = option
    """
    option child of collision_cross_section.
    """
    cross_section_multicomponent: cross_section_multicomponent = cross_section_multicomponent
    """
    cross_section_multicomponent child of collision_cross_section.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .low_re_ke import low_re_ke
from .low_re_ke_index import low_re_ke_index
from .kato_launder_model import kato_launder_model
from .production_limiter import production_limiter
from .kw_vorticity_based_production import kw_vorticity_based_production
from .kw_add_sas import kw_add_sas
from .kw_add_des import kw_add_des
from .turb_add_sbes_sdes import turb_add_sbes_sdes
from .sbes_sdes_hybrid_model import sbes_sdes_hybrid_model
from .sbes_update_interval_k_omega import sbes_update_interval_k_omega
from .sbes_sgs_option import sbes_sgs_option
from .sbes_les_subgrid_dynamic_fvar import sbes_les_subgrid_dynamic_fvar
from .turbulence_damping import turbulence_damping
from .rke_cmu_rotation_term import rke_cmu_rotation_term
from .turb_non_newtonian import turb_non_newtonian
from .non_newtonian_modification import non_newtonian_modification
from .turb_pk_compressible import turb_pk_compressible
from .thermal_p_function import thermal_p_function
from .restore_sst_v61 import restore_sst_v61
class turbulence_expert(Group):
    """
    'turbulence_expert' child.
    """

    fluent_name = "turbulence-expert"

    child_names = \
        ['low_re_ke', 'low_re_ke_index', 'kato_launder_model',
         'production_limiter', 'kw_vorticity_based_production', 'kw_add_sas',
         'kw_add_des', 'turb_add_sbes_sdes', 'sbes_sdes_hybrid_model',
         'sbes_update_interval_k_omega', 'sbes_sgs_option',
         'sbes_les_subgrid_dynamic_fvar', 'turbulence_damping',
         'rke_cmu_rotation_term', 'turb_non_newtonian',
         'non_newtonian_modification', 'turb_pk_compressible',
         'thermal_p_function', 'restore_sst_v61']

    low_re_ke: low_re_ke = low_re_ke
    """
    low_re_ke child of turbulence_expert.
    """
    low_re_ke_index: low_re_ke_index = low_re_ke_index
    """
    low_re_ke_index child of turbulence_expert.
    """
    kato_launder_model: kato_launder_model = kato_launder_model
    """
    kato_launder_model child of turbulence_expert.
    """
    production_limiter: production_limiter = production_limiter
    """
    production_limiter child of turbulence_expert.
    """
    kw_vorticity_based_production: kw_vorticity_based_production = kw_vorticity_based_production
    """
    kw_vorticity_based_production child of turbulence_expert.
    """
    kw_add_sas: kw_add_sas = kw_add_sas
    """
    kw_add_sas child of turbulence_expert.
    """
    kw_add_des: kw_add_des = kw_add_des
    """
    kw_add_des child of turbulence_expert.
    """
    turb_add_sbes_sdes: turb_add_sbes_sdes = turb_add_sbes_sdes
    """
    turb_add_sbes_sdes child of turbulence_expert.
    """
    sbes_sdes_hybrid_model: sbes_sdes_hybrid_model = sbes_sdes_hybrid_model
    """
    sbes_sdes_hybrid_model child of turbulence_expert.
    """
    sbes_update_interval_k_omega: sbes_update_interval_k_omega = sbes_update_interval_k_omega
    """
    sbes_update_interval_k_omega child of turbulence_expert.
    """
    sbes_sgs_option: sbes_sgs_option = sbes_sgs_option
    """
    sbes_sgs_option child of turbulence_expert.
    """
    sbes_les_subgrid_dynamic_fvar: sbes_les_subgrid_dynamic_fvar = sbes_les_subgrid_dynamic_fvar
    """
    sbes_les_subgrid_dynamic_fvar child of turbulence_expert.
    """
    turbulence_damping: turbulence_damping = turbulence_damping
    """
    turbulence_damping child of turbulence_expert.
    """
    rke_cmu_rotation_term: rke_cmu_rotation_term = rke_cmu_rotation_term
    """
    rke_cmu_rotation_term child of turbulence_expert.
    """
    turb_non_newtonian: turb_non_newtonian = turb_non_newtonian
    """
    turb_non_newtonian child of turbulence_expert.
    """
    non_newtonian_modification: non_newtonian_modification = non_newtonian_modification
    """
    non_newtonian_modification child of turbulence_expert.
    """
    turb_pk_compressible: turb_pk_compressible = turb_pk_compressible
    """
    turb_pk_compressible child of turbulence_expert.
    """
    thermal_p_function: thermal_p_function = thermal_p_function
    """
    thermal_p_function child of turbulence_expert.
    """
    restore_sst_v61: restore_sst_v61 = restore_sst_v61
    """
    restore_sst_v61 child of turbulence_expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use_inherent_material_color_1 import use_inherent_material_color
from .reset import reset
from .list_surfaces_by_color import list_surfaces_by_color
from .list_surfaces_by_material import list_surfaces_by_material
class by_surface(Group):
    """
    'by_surface' child.
    """

    fluent_name = "by-surface"

    child_names = \
        ['use_inherent_material_color']

    use_inherent_material_color: use_inherent_material_color = use_inherent_material_color
    """
    use_inherent_material_color child of by_surface.
    """
    command_names = \
        ['reset', 'list_surfaces_by_color', 'list_surfaces_by_material']

    reset: reset = reset
    """
    reset command of by_surface.
    """
    list_surfaces_by_color: list_surfaces_by_color = list_surfaces_by_color
    """
    list_surfaces_by_color command of by_surface.
    """
    list_surfaces_by_material: list_surfaces_by_material = list_surfaces_by_material
    """
    list_surfaces_by_material command of by_surface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_origin import axis_origin
from .axis_direction import axis_direction
from .radial_diffusivity import radial_diffusivity
from .tangential_diffusivity import tangential_diffusivity
from .axial_diffusivity import axial_diffusivity
class cyl_orthotropic(Group):
    """
    'cyl_orthotropic' child.
    """

    fluent_name = "cyl-orthotropic"

    child_names = \
        ['axis_origin', 'axis_direction', 'radial_diffusivity',
         'tangential_diffusivity', 'axial_diffusivity']

    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of cyl_orthotropic.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of cyl_orthotropic.
    """
    radial_diffusivity: radial_diffusivity = radial_diffusivity
    """
    radial_diffusivity child of cyl_orthotropic.
    """
    tangential_diffusivity: tangential_diffusivity = tangential_diffusivity
    """
    tangential_diffusivity child of cyl_orthotropic.
    """
    axial_diffusivity: axial_diffusivity = axial_diffusivity
    """
    axial_diffusivity child of cyl_orthotropic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class alternate_diffusion_for_porous_region_solids(Boolean):
    """
    Enable/disable use of alternate diffusion for porous region solids.
    """

    fluent_name = "alternate-diffusion-for-porous-region-solids?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .retain_instantaneous_values import retain_instantaneous_values
from .list_valid_report_names import list_valid_report_names
from .define import define
from .average_over import average_over
from .old_props import old_props
class single_val_expression_child(Group):
    """
    'child_object_type' of single_val_expression.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['retain_instantaneous_values', 'list_valid_report_names', 'define',
         'average_over', 'old_props']

    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of single_val_expression_child.
    """
    list_valid_report_names: list_valid_report_names = list_valid_report_names
    """
    list_valid_report_names child of single_val_expression_child.
    """
    define: define = define
    """
    define child of single_val_expression_child.
    """
    average_over: average_over = average_over
    """
    average_over child of single_val_expression_child.
    """
    old_props: old_props = old_props
    """
    old_props child of single_val_expression_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .mass_flow_inlet_child import mass_flow_inlet_child

class mass_flow_inlet(NamedObject[mass_flow_inlet_child], _CreatableNamedObjectMixin[mass_flow_inlet_child]):
    """
    'mass_flow_inlet' child.
    """

    fluent_name = "mass-flow-inlet"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of mass_flow_inlet.
    """
    child_object_type: mass_flow_inlet_child = mass_flow_inlet_child
    """
    child_object_type of mass_flow_inlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class number_of_timesteps(Integer):
    """
    Set number of timesteps for ramping of sources.
    """

    fluent_name = "number-of-timesteps"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class time_step_size_for_acoustic_export(Real):
    """
    Set number of time step size for acoustic export.
    """

    fluent_name = "time-step-size-for-acoustic-export"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class include_local_polyhedra_conversion_in_repair(Boolean):
    """
    Enable/disable local conversion to polyhedra during mesh repair.
    """

    fluent_name = "include-local-polyhedra-conversion-in-repair?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class option(Boolean):
    """
    Enable/disable virtual mass force acting on particles. This force term may be important if the particle density is equal to or less than the local fluid density.
    """

    fluent_name = "option"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_velocity import x_velocity
from .x_velocity_2 import x_velocity_2
from .y_velocity import y_velocity
from .y_velocity_2 import y_velocity_2
from .z_velocity import z_velocity
from .z_velocity_2 import z_velocity_2
from .magnitude import magnitude
from .swirl_fraction import swirl_fraction
from .use_face_normal_direction import use_face_normal_direction
class velocity(Group):
    """
    'velocity' child.
    """

    fluent_name = "velocity"

    child_names = \
        ['x_velocity', 'x_velocity_2', 'y_velocity', 'y_velocity_2',
         'z_velocity', 'z_velocity_2', 'magnitude', 'swirl_fraction',
         'use_face_normal_direction']

    x_velocity: x_velocity = x_velocity
    """
    x_velocity child of velocity.
    """
    x_velocity_2: x_velocity_2 = x_velocity_2
    """
    x_velocity_2 child of velocity.
    """
    y_velocity: y_velocity = y_velocity
    """
    y_velocity child of velocity.
    """
    y_velocity_2: y_velocity_2 = y_velocity_2
    """
    y_velocity_2 child of velocity.
    """
    z_velocity: z_velocity = z_velocity
    """
    z_velocity child of velocity.
    """
    z_velocity_2: z_velocity_2 = z_velocity_2
    """
    z_velocity_2 child of velocity.
    """
    magnitude: magnitude = magnitude
    """
    magnitude child of velocity.
    """
    swirl_fraction: swirl_fraction = swirl_fraction
    """
    swirl_fraction child of velocity.
    """
    use_face_normal_direction: use_face_normal_direction = use_face_normal_direction
    """
    use_face_normal_direction child of velocity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .variable_lewis_number import variable_lewis_number
from .use_vapor_species_heat_capacity import use_vapor_species_heat_capacity
class convection_diffusion_controlled(Group):
    """
    'convection_diffusion_controlled' child.
    """

    fluent_name = "convection-diffusion-controlled"

    child_names = \
        ['variable_lewis_number', 'use_vapor_species_heat_capacity']

    variable_lewis_number: variable_lewis_number = variable_lewis_number
    """
    variable_lewis_number child of convection_diffusion_controlled.
    """
    use_vapor_species_heat_capacity: use_vapor_species_heat_capacity = use_vapor_species_heat_capacity
    """
    use_vapor_species_heat_capacity child of convection_diffusion_controlled.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .relaxation_factor_2 import relaxation_factor
from .select_variables import select_variables
from .relaxation_options import relaxation_options
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['relaxation_factor', 'select_variables', 'relaxation_options']

    relaxation_factor: relaxation_factor = relaxation_factor
    """
    relaxation_factor child of options.
    """
    select_variables: select_variables = select_variables
    """
    select_variables child of options.
    """
    relaxation_options: relaxation_options = relaxation_options
    """
    relaxation_options child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mesh_1 import mesh
from .surface_1 import surface
from .volume import volume
from .force import force
from .lift import lift
from .drag import drag
from .moment import moment
from .flux_1 import flux
from .injection import injection
from .user_defined_1 import user_defined
from .aeromechanics import aeromechanics
from .icing import icing
from .expression_1 import expression
from .single_val_expression import single_val_expression
from .custom import custom
from .compute_1 import compute
from .copy_1 import copy
from .list import list
class report_definitions(Group, _ChildNamedObjectAccessorMixin):
    """
    'report_definitions' child.
    """

    fluent_name = "report-definitions"

    child_names = \
        ['mesh', 'surface', 'volume', 'force', 'lift', 'drag', 'moment',
         'flux', 'injection', 'user_defined', 'aeromechanics', 'icing',
         'expression', 'single_val_expression', 'custom']

    mesh: mesh = mesh
    """
    mesh child of report_definitions.
    """
    surface: surface = surface
    """
    surface child of report_definitions.
    """
    volume: volume = volume
    """
    volume child of report_definitions.
    """
    force: force = force
    """
    force child of report_definitions.
    """
    lift: lift = lift
    """
    lift child of report_definitions.
    """
    drag: drag = drag
    """
    drag child of report_definitions.
    """
    moment: moment = moment
    """
    moment child of report_definitions.
    """
    flux: flux = flux
    """
    flux child of report_definitions.
    """
    injection: injection = injection
    """
    injection child of report_definitions.
    """
    user_defined: user_defined = user_defined
    """
    user_defined child of report_definitions.
    """
    aeromechanics: aeromechanics = aeromechanics
    """
    aeromechanics child of report_definitions.
    """
    icing: icing = icing
    """
    icing child of report_definitions.
    """
    expression: expression = expression
    """
    expression child of report_definitions.
    """
    single_val_expression: single_val_expression = single_val_expression
    """
    single_val_expression child of report_definitions.
    """
    custom: custom = custom
    """
    custom child of report_definitions.
    """
    command_names = \
        ['compute', 'copy', 'list']

    compute: compute = compute
    """
    compute command of report_definitions.
    """
    copy: copy = copy
    """
    copy command of report_definitions.
    """
    list: list = list
    """
    list command of report_definitions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class accelerated_non_iterative_time_marching(Boolean):
    """
    Enable/disable accelerated non-iterative time marching.
    """

    fluent_name = "accelerated-non-iterative-time-marching?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .command_name_1 import command_name
from .tsv_file_name import tsv_file_name
class export(Command):
    """
    Export execute-commands to a TSV file.
    
    Parameters
    ----------
        command_name : typing.List[str]
            'command_name' child.
        tsv_file_name : str
            'tsv_file_name' child.
    
    """

    fluent_name = "export"

    argument_names = \
        ['command_name', 'tsv_file_name']

    command_name: command_name = command_name
    """
    command_name argument of export.
    """
    tsv_file_name: tsv_file_name = tsv_file_name
    """
    tsv_file_name argument of export.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .xy_plot import xy_plot
class plot(Group):
    """
    'plot' child.
    """

    fluent_name = "plot"

    child_names = \
        ['xy_plot']

    xy_plot: xy_plot = xy_plot
    """
    xy_plot child of plot.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_roughness_correlation import enable_roughness_correlation
from .roughness_correlation_fcn import roughness_correlation_fcn
from .geometric_roughness_ht_val import geometric_roughness_ht_val
class transition_sst_option(Group):
    """
    'transition_sst_option' child.
    """

    fluent_name = "transition-sst-option"

    child_names = \
        ['enable_roughness_correlation', 'roughness_correlation_fcn',
         'geometric_roughness_ht_val']

    enable_roughness_correlation: enable_roughness_correlation = enable_roughness_correlation
    """
    enable_roughness_correlation child of transition_sst_option.
    """
    roughness_correlation_fcn: roughness_correlation_fcn = roughness_correlation_fcn
    """
    roughness_correlation_fcn child of transition_sst_option.
    """
    geometric_roughness_ht_val: geometric_roughness_ht_val = geometric_roughness_ht_val
    """
    geometric_roughness_ht_val child of transition_sst_option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .user_defined_functions_1 import user_defined_functions
from .sort_sample_files import sort_sample_files
from .sample_1 import sample
class sample_trajectories(Group):
    """
    'sample_trajectories' child.
    """

    fluent_name = "sample-trajectories"

    child_names = \
        ['user_defined_functions', 'sort_sample_files']

    user_defined_functions: user_defined_functions = user_defined_functions
    """
    user_defined_functions child of sample_trajectories.
    """
    sort_sample_files: sort_sample_files = sort_sample_files
    """
    sort_sample_files child of sample_trajectories.
    """
    command_names = \
        ['sample']

    sample: sample = sample
    """
    sample command of sample_trajectories.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_name import report_name
from .file_name_path import file_name_path
class export_simulation_report_as_pdf(Command):
    """
    Export the provided simulation report as a PDF file.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
        file_name_path : str
            'file_name_path' child.
    
    """

    fluent_name = "export-simulation-report-as-pdf"

    argument_names = \
        ['report_name', 'file_name_path']

    report_name: report_name = report_name
    """
    report_name argument of export_simulation_report_as_pdf.
    """
    file_name_path: file_name_path = file_name_path
    """
    file_name_path argument of export_simulation_report_as_pdf.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .smooth_partitioning import smooth_partitioning
from .max_smoothing_iterations import max_smoothing_iterations
class smooth(Group):
    """
    Set partition smoothing optimization.
    """

    fluent_name = "smooth"

    child_names = \
        ['smooth_partitioning', 'max_smoothing_iterations']

    smooth_partitioning: smooth_partitioning = smooth_partitioning
    """
    smooth_partitioning child of smooth.
    """
    max_smoothing_iterations: max_smoothing_iterations = max_smoothing_iterations
    """
    max_smoothing_iterations child of smooth.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .a import a
from .b import b
from .c import c
class blottner_curve_fit(Group):
    """
    'blottner_curve_fit' child.
    """

    fluent_name = "blottner-curve-fit"

    child_names = \
        ['a', 'b', 'c']

    a: a = a
    """
    a child of blottner_curve_fit.
    """
    b: b = b
    """
    b child of blottner_curve_fit.
    """
    c: c = c
    """
    c child of blottner_curve_fit.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .set_velocity_and_vof_cutoffs_child import set_velocity_and_vof_cutoffs_child

class set_velocity_and_vof_cutoffs(NamedObject[set_velocity_and_vof_cutoffs_child], _NonCreatableNamedObjectMixin[set_velocity_and_vof_cutoffs_child]):
    """
    'set_velocity_and_vof_cutoffs' child.
    """

    fluent_name = "set-velocity-and-vof-cutoffs"

    child_object_type: set_velocity_and_vof_cutoffs_child = set_velocity_and_vof_cutoffs_child
    """
    child_object_type of set_velocity_and_vof_cutoffs.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .source_terms_child import source_terms_child

class source_terms(NamedObject[source_terms_child], _CreatableNamedObjectMixin[source_terms_child]):
    """
    'source_terms' child.
    """

    fluent_name = "source-terms"

    child_object_type: source_terms_child = source_terms_child
    """
    child_object_type of source_terms.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .rans_les_interface_child import rans_les_interface_child

class rans_les_interface(NamedObject[rans_les_interface_child], _CreatableNamedObjectMixin[rans_les_interface_child]):
    """
    'rans_les_interface' child.
    """

    fluent_name = "rans-les-interface"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of rans_les_interface.
    """
    child_object_type: rans_les_interface_child = rans_les_interface_child
    """
    child_object_type of rans_les_interface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .file_name_path_1 import file_name_path
class write_simulation_report_template_file(Command):
    """
    'write_simulation_report_template_file' command.
    
    Parameters
    ----------
        file_name_path : str
            'file_name_path' child.
    
    """

    fluent_name = "write-simulation-report-template-file"

    argument_names = \
        ['file_name_path']

    file_name_path: file_name_path = file_name_path
    """
    file_name_path argument of write_simulation_report_template_file.
    """



"""Wrapper over the transcript grpc service of Fluent."""

from typing import List, Tuple

import grpc

from ansys.api.fluent.v0 import transcript_pb2 as TranscriptModule
from ansys.api.fluent.v0 import transcript_pb2_grpc as TranscriptGrpcModule
from ansys.fluent.core.services.streaming import StreamingService


class TranscriptService(StreamingService):
    """Class wrapping the transcript gRPC service of Fluent."""

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        super().__init__(
            stub=TranscriptGrpcModule.TranscriptStub(channel),
            request=TranscriptModule.TranscriptRequest(),
            metadata=metadata,
        )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class sbes_sgs_option(String):
    """
    Select SBES subgrid-scale model.
    """

    fluent_name = "sbes-sgs-option"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .network_end_child import network_end_child

class network_end(NamedObject[network_end_child], _CreatableNamedObjectMixin[network_end_child]):
    """
    'network_end' child.
    """

    fluent_name = "network-end"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of network_end.
    """
    child_object_type: network_end_child = network_end_child
    """
    child_object_type of network_end.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .hostname import hostname
from .username import username
class spawn_node(Command):
    """
    Spawn a compute node process on a specified machine.
    
    Parameters
    ----------
        hostname : str
            'hostname' child.
        username : str
            'username' child.
    
    """

    fluent_name = "spawn-node"

    argument_names = \
        ['hostname', 'username']

    hostname: hostname = hostname
    """
    hostname argument of spawn_node.
    """
    username: username = username
    """
    username argument of spawn_node.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class migrate_and_reorder(Boolean):
    """
    Perform migration and reordering at the end of the polyhedra conversion.
    """

    fluent_name = "migrate-and-reorder?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .refine_mesh import refine_mesh
from .boundary_zones import boundary_zones
from .layer_count import layer_count
from .parameters import parameters
class multi_layer_refinement(Group):
    """
    Enter the multiple boundary layer refinement menu.
    """

    fluent_name = "multi-layer-refinement"

    command_names = \
        ['refine_mesh', 'boundary_zones', 'layer_count', 'parameters']

    refine_mesh: refine_mesh = refine_mesh
    """
    refine_mesh command of multi_layer_refinement.
    """
    boundary_zones: boundary_zones = boundary_zones
    """
    boundary_zones command of multi_layer_refinement.
    """
    layer_count: layer_count = layer_count
    """
    layer_count command of multi_layer_refinement.
    """
    parameters: parameters = parameters
    """
    parameters command of multi_layer_refinement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
from .uid import uid
from .options_5 import options
from .range import range
from .style_attribute import style_attribute
from .accuracy_control import accuracy_control
from .plot import plot
from .step import step
from .skip import skip
from .coarsen import coarsen
from .onzone import onzone
from .field import field
from .surfaces_list import surfaces_list
from .velocity_domain import velocity_domain
from .color_map import color_map
from .draw_mesh import draw_mesh
from .mesh_object import mesh_object
from .display_state_name import display_state_name
from .physics import physics
from .geometry_1 import geometry
from .surfaces import surfaces
from .display_1 import display
class pathlines_child(Group):
    """
    'child_object_type' of pathlines.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'range', 'style_attribute',
         'accuracy_control', 'plot', 'step', 'skip', 'coarsen', 'onzone',
         'field', 'surfaces_list', 'velocity_domain', 'color_map',
         'draw_mesh', 'mesh_object', 'display_state_name', 'physics',
         'geometry', 'surfaces']

    name: name = name
    """
    name child of pathlines_child.
    """
    uid: uid = uid
    """
    uid child of pathlines_child.
    """
    options: options = options
    """
    options child of pathlines_child.
    """
    range: range = range
    """
    range child of pathlines_child.
    """
    style_attribute: style_attribute = style_attribute
    """
    style_attribute child of pathlines_child.
    """
    accuracy_control: accuracy_control = accuracy_control
    """
    accuracy_control child of pathlines_child.
    """
    plot: plot = plot
    """
    plot child of pathlines_child.
    """
    step: step = step
    """
    step child of pathlines_child.
    """
    skip: skip = skip
    """
    skip child of pathlines_child.
    """
    coarsen: coarsen = coarsen
    """
    coarsen child of pathlines_child.
    """
    onzone: onzone = onzone
    """
    onzone child of pathlines_child.
    """
    field: field = field
    """
    field child of pathlines_child.
    """
    surfaces_list: surfaces_list = surfaces_list
    """
    surfaces_list child of pathlines_child.
    """
    velocity_domain: velocity_domain = velocity_domain
    """
    velocity_domain child of pathlines_child.
    """
    color_map: color_map = color_map
    """
    color_map child of pathlines_child.
    """
    draw_mesh: draw_mesh = draw_mesh
    """
    draw_mesh child of pathlines_child.
    """
    mesh_object: mesh_object = mesh_object
    """
    mesh_object child of pathlines_child.
    """
    display_state_name: display_state_name = display_state_name
    """
    display_state_name child of pathlines_child.
    """
    physics: physics = physics
    """
    physics child of pathlines_child.
    """
    geometry: geometry = geometry
    """
    geometry child of pathlines_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of pathlines_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of pathlines_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .xyz import xyz
class position(Command):
    """
    Set the camera position.
    
    Parameters
    ----------
        xyz : typing.List[real]
            'xyz' child.
    
    """

    fluent_name = "position"

    argument_names = \
        ['xyz']

    xyz: xyz = xyz
    """
    xyz argument of position.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .color_mode import color_mode
from .invert_background import invert_background
from .driver_options import driver_options
from .standard_resolution import standard_resolution
from .jpeg_hardcopy_quality import jpeg_hardcopy_quality
from .landscape import landscape
from .x_resolution import x_resolution
from .y_resolution import y_resolution
from .dpi import dpi
from .use_window_resolution import use_window_resolution
from .list_color_mode import list_color_mode
from .preview import preview
class picture_options(Group):
    """
    'picture_options' child.
    """

    fluent_name = "picture-options"

    child_names = \
        ['color_mode', 'invert_background', 'driver_options',
         'standard_resolution', 'jpeg_hardcopy_quality', 'landscape',
         'x_resolution', 'y_resolution', 'dpi', 'use_window_resolution']

    color_mode: color_mode = color_mode
    """
    color_mode child of picture_options.
    """
    invert_background: invert_background = invert_background
    """
    invert_background child of picture_options.
    """
    driver_options: driver_options = driver_options
    """
    driver_options child of picture_options.
    """
    standard_resolution: standard_resolution = standard_resolution
    """
    standard_resolution child of picture_options.
    """
    jpeg_hardcopy_quality: jpeg_hardcopy_quality = jpeg_hardcopy_quality
    """
    jpeg_hardcopy_quality child of picture_options.
    """
    landscape: landscape = landscape
    """
    landscape child of picture_options.
    """
    x_resolution: x_resolution = x_resolution
    """
    x_resolution child of picture_options.
    """
    y_resolution: y_resolution = y_resolution
    """
    y_resolution child of picture_options.
    """
    dpi: dpi = dpi
    """
    dpi child of picture_options.
    """
    use_window_resolution: use_window_resolution = use_window_resolution
    """
    use_window_resolution child of picture_options.
    """
    command_names = \
        ['list_color_mode', 'preview']

    list_color_mode: list_color_mode = list_color_mode
    """
    list_color_mode command of picture_options.
    """
    preview: preview = preview
    """
    preview command of picture_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class root_name(String):
    """
    Set the root name for auto-saved files. The number of iterations or time steps will be appended to this root name.
    """

    fluent_name = "root-name"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .polar_real_angle import polar_real_angle
from .polar_real_intensity import polar_real_intensity
class polar_pair_list_child(Group):
    """
    'child_object_type' of polar_pair_list.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['polar_real_angle', 'polar_real_intensity']

    polar_real_angle: polar_real_angle = polar_real_angle
    """
    polar_real_angle child of polar_pair_list_child.
    """
    polar_real_intensity: polar_real_intensity = polar_real_intensity
    """
    polar_real_intensity child of polar_pair_list_child.
    """



"""A package providing Fluent's Solver and Meshing capabilities in Python."""

import os
from typing import Any, Optional

import appdirs

from ansys.fluent.core._version import __version__  # noqa: F401
from ansys.fluent.core.launcher.launcher import (  # noqa: F401
    FluentVersion,
    LaunchModes,
    get_ansys_version,
    launch_fluent,
    set_ansys_version,
    set_fluent_path,
)
from ansys.fluent.core.session import _BaseSession as Fluent  # noqa: F401
from ansys.fluent.core.utils.logging import LOG
from ansys.fluent.core.utils.setup_for_fluent import setup_for_fluent  # noqa: F401

_VERSION_INFO = "Build date: January 06, 2023 19:41 UTC ShaID: 67fe6b0"
"""Global variable indicating the version of the PyFluent package - Empty by default"""

_THIS_DIRNAME = os.path.dirname(__file__)
_README_FILE = os.path.normpath(os.path.join(_THIS_DIRNAME, "docs", "README.rst"))

if os.path.exists(_README_FILE):
    with open(_README_FILE, encoding="utf8") as f:
        __doc__ = f.read()


def version_info() -> str:
    """Method returning the version of PyFluent being used.

    Returns
    -------
    str
        The PyFluent version being used.

    Notes
    -------
    Only available in packaged versions. Otherwise it will return __version__.
    """
    return _VERSION_INFO if _VERSION_INFO is not None else __version__


def set_log_level(level: Any) -> None:
    """Set logging level.

    Parameters
    ----------
    level : Any
        Any of the logging level (CRITICAL, ERROR, WARNING, INFO, DEBUG)
        in string or enum format
    """
    LOG.set_level(level)


def enable_logging_to_stdout() -> None:
    """Enable logging to stdout."""
    LOG.enable_logging_to_stdout()


def disable_logging_to_stdout() -> None:
    """Disable logging to stdout."""
    LOG.disable_logging_to_stdout()


def enable_logging_to_file(filepath: Optional[str] = None) -> None:
    """Enable logging to file.

    Parameters
    ----------
    filepath : str, optional
        filapath, a default filepath will be chosen if filepath is not
        passed
    """
    LOG.enable_logging_to_file(filepath)


def disable_logging_to_file() -> None:
    """Disable logging to file."""
    LOG.disable_logging_to_file()


# Setup data directory
try:
    USER_DATA_PATH = appdirs.user_data_dir("ansys_fluent_core")
    if not os.path.exists(USER_DATA_PATH):
        os.makedirs(USER_DATA_PATH)

    EXAMPLES_PATH = os.path.join(USER_DATA_PATH, "examples")
    if not os.path.exists(EXAMPLES_PATH):
        os.makedirs(EXAMPLES_PATH)

except Exception:
    pass

BUILDING_GALLERY = False



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .compute_node import compute_node
from .invalidate_case import invalidate_case
class kill_node(Command):
    """
    'kill_node' command.
    
    Parameters
    ----------
        compute_node : int
            'compute_node' child.
        invalidate_case : bool
            'invalidate_case' child.
    
    """

    fluent_name = "kill-node"

    argument_names = \
        ['compute_node', 'invalidate_case']

    compute_node: compute_node = compute_node
    """
    compute_node argument of kill_node.
    """
    invalidate_case: invalidate_case = invalidate_case
    """
    invalidate_case argument of kill_node.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .design_point import design_point
class duplicate(Command):
    """
    Duplicate Design Point.
    
    Parameters
    ----------
        design_point : str
            'design_point' child.
    
    """

    fluent_name = "duplicate"

    argument_names = \
        ['design_point']

    design_point: design_point = design_point
    """
    design_point argument of duplicate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .radius_ratio import radius_ratio
from .chord import chord
from .twist import twist
from .airfoil_data_file import airfoil_data_file
class geometry_child(Group):
    """
    'child_object_type' of geometry.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['radius_ratio', 'chord', 'twist', 'airfoil_data_file']

    radius_ratio: radius_ratio = radius_ratio
    """
    radius_ratio child of geometry_child.
    """
    chord: chord = chord
    """
    chord child of geometry_child.
    """
    twist: twist = twist
    """
    twist child of geometry_child.
    """
    airfoil_data_file: airfoil_data_file = airfoil_data_file
    """
    airfoil_data_file child of geometry_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_pseudo_time_method import enable_pseudo_time_method
from .pseudo_time_scale_factor import pseudo_time_scale_factor
from .implicit_under_relaxation_factor import implicit_under_relaxation_factor
class local_dt_child(Group):
    """
    'child_object_type' of local_dt.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['enable_pseudo_time_method', 'pseudo_time_scale_factor',
         'implicit_under_relaxation_factor']

    enable_pseudo_time_method: enable_pseudo_time_method = enable_pseudo_time_method
    """
    enable_pseudo_time_method child of local_dt_child.
    """
    pseudo_time_scale_factor: pseudo_time_scale_factor = pseudo_time_scale_factor
    """
    pseudo_time_scale_factor child of local_dt_child.
    """
    implicit_under_relaxation_factor: implicit_under_relaxation_factor = implicit_under_relaxation_factor
    """
    implicit_under_relaxation_factor child of local_dt_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .limiter_type import limiter_type
from .cell_to_limiting import cell_to_limiting
from .limiter_filter import limiter_filter
class spatial_discretization_limiter(Group):
    """
    'spatial_discretization_limiter' child.
    """

    fluent_name = "spatial-discretization-limiter"

    child_names = \
        ['limiter_type', 'cell_to_limiting', 'limiter_filter']

    limiter_type: limiter_type = limiter_type
    """
    limiter_type child of spatial_discretization_limiter.
    """
    cell_to_limiting: cell_to_limiting = cell_to_limiting
    """
    cell_to_limiting child of spatial_discretization_limiter.
    """
    limiter_filter: limiter_filter = limiter_filter
    """
    limiter_filter child of spatial_discretization_limiter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .consistency_index import consistency_index
from .power_law_index import power_law_index
from .yield_stress_threshold import yield_stress_threshold
from .critical_shear_rate import critical_shear_rate
from .reference_temperature import reference_temperature
from .activation_energy import activation_energy
class herschel_bulkley(Group):
    """
    'herschel_bulkley' child.
    """

    fluent_name = "herschel-bulkley"

    child_names = \
        ['option', 'consistency_index', 'power_law_index',
         'yield_stress_threshold', 'critical_shear_rate',
         'reference_temperature', 'activation_energy']

    option: option = option
    """
    option child of herschel_bulkley.
    """
    consistency_index: consistency_index = consistency_index
    """
    consistency_index child of herschel_bulkley.
    """
    power_law_index: power_law_index = power_law_index
    """
    power_law_index child of herschel_bulkley.
    """
    yield_stress_threshold: yield_stress_threshold = yield_stress_threshold
    """
    yield_stress_threshold child of herschel_bulkley.
    """
    critical_shear_rate: critical_shear_rate = critical_shear_rate
    """
    critical_shear_rate child of herschel_bulkley.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of herschel_bulkley.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of herschel_bulkley.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class high_order_scheme(String):
    """
    Select a high-order tracking scheme used for automated tracking scheme selection.
    """

    fluent_name = "high-order-scheme"




class Meshing:
    def __init__(self, session_execute_tui, meshing, tui, fluent_connection):
        self.execute_tui = session_execute_tui
        self._meshing = meshing
        self._tui = tui
        self._fluent_connection = fluent_connection

    def switch_to_solver(self):
        """Switch to solver session."""
        from ansys.fluent.core.session_solver import Solver

        self._tui.switch_to_solution_mode("yes")
        solver_session = Solver(fluent_connection=self._fluent_connection)
        return solver_session

    def __getattr__(self, attr):
        return getattr(self._meshing, attr)

    def __dir__(self):
        return sorted(
            set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._meshing))
        )

    def __call__(self):
        return self._meshing()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .right import right
from .up import up
class pan(Command):
    """
    Adjust the camera position without modifying the position.
    
    Parameters
    ----------
        right : real
            'right' child.
        up : real
            'up' child.
    
    """

    fluent_name = "pan"

    argument_names = \
        ['right', 'up']

    right: right = right
    """
    right argument of pan.
    """
    up: up = up
    """
    up argument of pan.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .direction_0 import direction_0
from .direction_1 import direction_1
from .youngs_modulus_0 import youngs_modulus_0
from .youngs_modulus_1 import youngs_modulus_1
from .youngs_modulus_2 import youngs_modulus_2
from .shear_modulus_01 import shear_modulus_01
from .shear_modulus_12 import shear_modulus_12
from .shear_modulus_02 import shear_modulus_02
class orthotropic_structure_ym(Group):
    """
    'orthotropic_structure_ym' child.
    """

    fluent_name = "orthotropic-structure-ym"

    child_names = \
        ['direction_0', 'direction_1', 'youngs_modulus_0', 'youngs_modulus_1',
         'youngs_modulus_2', 'shear_modulus_01', 'shear_modulus_12',
         'shear_modulus_02']

    direction_0: direction_0 = direction_0
    """
    direction_0 child of orthotropic_structure_ym.
    """
    direction_1: direction_1 = direction_1
    """
    direction_1 child of orthotropic_structure_ym.
    """
    youngs_modulus_0: youngs_modulus_0 = youngs_modulus_0
    """
    youngs_modulus_0 child of orthotropic_structure_ym.
    """
    youngs_modulus_1: youngs_modulus_1 = youngs_modulus_1
    """
    youngs_modulus_1 child of orthotropic_structure_ym.
    """
    youngs_modulus_2: youngs_modulus_2 = youngs_modulus_2
    """
    youngs_modulus_2 child of orthotropic_structure_ym.
    """
    shear_modulus_01: shear_modulus_01 = shear_modulus_01
    """
    shear_modulus_01 child of orthotropic_structure_ym.
    """
    shear_modulus_12: shear_modulus_12 = shear_modulus_12
    """
    shear_modulus_12 child of orthotropic_structure_ym.
    """
    shear_modulus_02: shear_modulus_02 = shear_modulus_02
    """
    shear_modulus_02 child of orthotropic_structure_ym.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_name import report_name
from .new_report_name import new_report_name
class rename_simulation_report(Command):
    """
    Rename a report which has already been generated.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
        new_report_name : str
            'new_report_name' child.
    
    """

    fluent_name = "rename-simulation-report"

    argument_names = \
        ['report_name', 'new_report_name']

    report_name: report_name = report_name
    """
    report_name argument of rename_simulation_report.
    """
    new_report_name: new_report_name = new_report_name
    """
    new_report_name argument of rename_simulation_report.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use import use
from .threshold import threshold
class mesh_adaption(Group):
    """
    Use load balancing for mesh adaption?.
    """

    fluent_name = "mesh-adaption"

    child_names = \
        ['use', 'threshold']

    use: use = use
    """
    use child of mesh_adaption.
    """
    threshold: threshold = threshold
    """
    threshold child of mesh_adaption.
    """



"""Module containing class encapsulating Fluent connection."""

from typing import Any

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.session_pure_meshing import PureMeshing
from ansys.fluent.core.session_solver import Solver


class Meshing(PureMeshing):
    """Encapsulates a Fluent - Meshing session connection.
    Meshing(PureMeshing) holds the top-level objects
    for meshing TUI and various meshing datamodel API calls.
    In this general meshing mode, switch to solver is available,
    after which"""

    def __init__(
        self,
        fluent_connection: _FluentConnection,
    ):
        super(Meshing, self).__init__(fluent_connection=fluent_connection)
        self.switch_to_solver = lambda: self._switch_to_solver()
        self.switched = False

    def _switch_to_solver(self) -> Any:
        self.tui.switch_to_solution_mode("yes")
        solver_session = Solver(fluent_connection=self.fluent_connection)
        delattr(self, "switch_to_solver")
        self.switched = True
        return solver_session

    @property
    def tui(self):
        """Instance of ``main_menu`` on which Fluent's SolverTUI methods can be
        executed."""
        return super(Meshing, self).tui if not self.switched else None

    @property
    def meshing(self):
        """meshing datamodel root."""
        return super(Meshing, self).meshing if not self.switched else None

    @property
    def workflow(self):
        """workflow datamodel root."""
        return super(Meshing, self).workflow if not self.switched else None

    @property
    def PartManagement(self):
        """PartManagement datamodel root."""
        return super(Meshing, self).PartManagement if not self.switched else None

    @property
    def PMFileManagement(self):
        """PMFileManagement datamodel root."""
        return super(Meshing, self).PMFileManagement if not self.switched else None

    @property
    def preferences(self):
        """preferences datamodel root."""
        return super(Meshing, self).preferences if not self.switched else None



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_axis_2 import x_axis
from .x_axis_min import x_axis_min
from .x_axis_max import x_axis_max
from .y_axis_2 import y_axis
from .y_axis_min import y_axis_min
from .y_axis_max import y_axis_max
class auto_scale(Group):
    """
    'auto_scale' child.
    """

    fluent_name = "auto-scale"

    child_names = \
        ['x_axis', 'x_axis_min', 'x_axis_max', 'y_axis', 'y_axis_min',
         'y_axis_max']

    x_axis: x_axis = x_axis
    """
    x_axis child of auto_scale.
    """
    x_axis_min: x_axis_min = x_axis_min
    """
    x_axis_min child of auto_scale.
    """
    x_axis_max: x_axis_max = x_axis_max
    """
    x_axis_max child of auto_scale.
    """
    y_axis: y_axis = y_axis
    """
    y_axis child of auto_scale.
    """
    y_axis_min: y_axis_min = y_axis_min
    """
    y_axis_min child of auto_scale.
    """
    y_axis_max: y_axis_max = y_axis_max
    """
    y_axis_max child of auto_scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .constant import constant
from .coefficients import coefficients
from .number_of_coefficients import number_of_coefficients
from .piecewise_linear import piecewise_linear
from .piecewise_polynomial import piecewise_polynomial
class conductivity_1(Group):
    """
    'conductivity_1' child.
    """

    fluent_name = "conductivity-1"

    child_names = \
        ['option', 'constant', 'coefficients', 'number_of_coefficients',
         'piecewise_linear', 'piecewise_polynomial']

    option: option = option
    """
    option child of conductivity_1.
    """
    constant: constant = constant
    """
    constant child of conductivity_1.
    """
    coefficients: coefficients = coefficients
    """
    coefficients child of conductivity_1.
    """
    number_of_coefficients: number_of_coefficients = number_of_coefficients
    """
    number_of_coefficients child of conductivity_1.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of conductivity_1.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of conductivity_1.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .invalidate_case import invalidate_case
from .delete_all_compute_nodes import delete_all_compute_nodes
class kill_all_nodes(Command):
    """
    Delete all compute nodes from virtual machine.
    
    Parameters
    ----------
        invalidate_case : bool
            'invalidate_case' child.
        delete_all_compute_nodes : bool
            'delete_all_compute_nodes' child.
    
    """

    fluent_name = "kill-all-nodes"

    argument_names = \
        ['invalidate_case', 'delete_all_compute_nodes']

    invalidate_case: invalidate_case = invalidate_case
    """
    invalidate_case argument of kill_all_nodes.
    """
    delete_all_compute_nodes: delete_all_compute_nodes = delete_all_compute_nodes
    """
    delete_all_compute_nodes argument of kill_all_nodes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .acoustics_wave_equation_controls import acoustics_wave_equation_controls
from .advanced import advanced
from .contact_solution_controls import contact_solution_controls
from .courant_number import courant_number
from .equations import equations
from .limits import limits
from .p_v_controls import p_v_controls
from .relaxation_factor_1 import relaxation_factor
from .set_controls_to_default import set_controls_to_default
from .under_relaxation import under_relaxation
class controls(Group):
    """
    'controls' child.
    """

    fluent_name = "controls"

    child_names = \
        ['acoustics_wave_equation_controls', 'advanced',
         'contact_solution_controls', 'courant_number', 'equations', 'limits',
         'p_v_controls', 'relaxation_factor', 'set_controls_to_default',
         'under_relaxation']

    acoustics_wave_equation_controls: acoustics_wave_equation_controls = acoustics_wave_equation_controls
    """
    acoustics_wave_equation_controls child of controls.
    """
    advanced: advanced = advanced
    """
    advanced child of controls.
    """
    contact_solution_controls: contact_solution_controls = contact_solution_controls
    """
    contact_solution_controls child of controls.
    """
    courant_number: courant_number = courant_number
    """
    courant_number child of controls.
    """
    equations: equations = equations
    """
    equations child of controls.
    """
    limits: limits = limits
    """
    limits child of controls.
    """
    p_v_controls: p_v_controls = p_v_controls
    """
    p_v_controls child of controls.
    """
    relaxation_factor: relaxation_factor = relaxation_factor
    """
    relaxation_factor child of controls.
    """
    set_controls_to_default: set_controls_to_default = set_controls_to_default
    """
    set_controls_to_default child of controls.
    """
    under_relaxation: under_relaxation = under_relaxation
    """
    under_relaxation child of controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class exclude_transient_term_in_face_pressure_calc(Boolean):
    """
    Enable/disale transient terms in face pressure calculation.
    """

    fluent_name = "exclude-transient-term-in-face-pressure-calc"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .band_width import band_width
from .reorder_domain import reorder_domain
from .reorder_zones import reorder_zones
class reorder(Group):
    """
    Enter the reorder domain menu.
    """

    fluent_name = "reorder"

    command_names = \
        ['band_width', 'reorder_domain', 'reorder_zones']

    band_width: band_width = band_width
    """
    band_width command of reorder.
    """
    reorder_domain: reorder_domain = reorder_domain
    """
    reorder_domain command of reorder.
    """
    reorder_zones: reorder_zones = reorder_zones
    """
    reorder_zones command of reorder.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_vf_allowed_for_blocking(Real):
    """
    Set the maximum value for the DPM volume fraction used in the continuous flow when the volume displacement option is active.
     A default of 0.95 is recommendend.
    """

    fluent_name = "max-vf-allowed-for-blocking"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
from .thread_name_list import thread_name_list
class mechanical_apdl(Command):
    """
    Write an Mechanical APDL file.
    
    Parameters
    ----------
        name : str
            'name' child.
        thread_name_list : typing.List[str]
            'thread_name_list' child.
    
    """

    fluent_name = "mechanical-apdl"

    argument_names = \
        ['name', 'thread_name_list']

    name: name = name
    """
    name argument of mechanical_apdl.
    """
    thread_name_list: thread_name_list = thread_name_list
    """
    thread_name_list argument of mechanical_apdl.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class allow_repair_at_boundaries(Boolean):
    """
    Enable/disable adjustment of boundary nodes during mesh repair.
    """

    fluent_name = "allow-repair-at-boundaries?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .turb_visc_func_mf_child import turb_visc_func_mf_child

class discretization_scheme(NamedObject[turb_visc_func_mf_child], _NonCreatableNamedObjectMixin[turb_visc_func_mf_child]):
    """
    'discretization_scheme' child.
    """

    fluent_name = "discretization-scheme"

    child_object_type: turb_visc_func_mf_child = turb_visc_func_mf_child
    """
    child_object_type of discretization_scheme.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class convergence_acc_std_meshes(Boolean):
    """
    Enable/disable use of convergence acceleration for stretched meshes (CASM).
    """

    fluent_name = "convergence-acc-std-meshes?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .zone_ids import zone_ids
from .retain_instantaneous_values import retain_instantaneous_values
from .old_props import old_props
from .zone_names import zone_names
from .zone_list import zone_list
from .average_over import average_over
from .per_zone import per_zone
class mesh_child(Group):
    """
    'child_object_type' of mesh.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['zone_ids', 'retain_instantaneous_values', 'old_props', 'zone_names',
         'zone_list', 'average_over', 'per_zone']

    zone_ids: zone_ids = zone_ids
    """
    zone_ids child of mesh_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of mesh_child.
    """
    old_props: old_props = old_props
    """
    old_props child of mesh_child.
    """
    zone_names: zone_names = zone_names
    """
    zone_names child of mesh_child.
    """
    zone_list: zone_list = zone_list
    """
    zone_list child of mesh_child.
    """
    average_over: average_over = average_over
    """
    average_over child of mesh_child.
    """
    per_zone: per_zone = per_zone
    """
    per_zone child of mesh_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class binary_legacy_files(Boolean):
    """
    Indicate whether to write binary or text format case and data files.
    """

    fluent_name = "binary-legacy-files?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .view_1 import view
class stored_view(Command):
    """
    Play the 3D animation sequence using the view stored in the sequence.
    
    Parameters
    ----------
        view : bool
            Yes: "Stored View", no: "Different View".
    
    """

    fluent_name = "stored-view?"

    argument_names = \
        ['view']

    view: view = view
    """
    view argument of stored_view.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type_1 import type
from .formula import formula
class copy_database_material_by_formula(Command):
    """
    'copy_database_material_by_formula' command.
    
    Parameters
    ----------
        type : str
            'type' child.
        formula : str
            'formula' child.
    
    """

    fluent_name = "copy-database-material-by-formula"

    argument_names = \
        ['type', 'formula']

    type: type = type
    """
    type argument of copy_database_material_by_formula.
    """
    formula: formula = formula
    """
    formula argument of copy_database_material_by_formula.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .c1 import c1
from .c2 import c2
from .reference_viscosity import reference_viscosity
from .reference_temperature import reference_temperature
from .effective_temperature import effective_temperature
class sutherland(Group):
    """
    'sutherland' child.
    """

    fluent_name = "sutherland"

    child_names = \
        ['option', 'c1', 'c2', 'reference_viscosity', 'reference_temperature',
         'effective_temperature']

    option: option = option
    """
    option child of sutherland.
    """
    c1: c1 = c1
    """
    c1 child of sutherland.
    """
    c2: c2 = c2
    """
    c2 child of sutherland.
    """
    reference_viscosity: reference_viscosity = reference_viscosity
    """
    reference_viscosity child of sutherland.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of sutherland.
    """
    effective_temperature: effective_temperature = effective_temperature
    """
    effective_temperature child of sutherland.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .coupling import coupling
from .helper_session_setup import helper_session_setup
from .helper_session import helper_session
class set(Group):
    """
    'set' child.
    """

    fluent_name = "set"

    child_names = \
        ['coupling', 'helper_session_setup', 'helper_session']

    coupling: coupling = coupling
    """
    coupling child of set.
    """
    helper_session_setup: helper_session_setup = helper_session_setup
    """
    helper_session_setup child of set.
    """
    helper_session: helper_session = helper_session
    """
    helper_session child of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .width import width
from .height import height
class aspect_ratio(Command):
    """
    Set the aspect ratio of the active window.
    
    Parameters
    ----------
        width : real
            'width' child.
        height : real
            'height' child.
    
    """

    fluent_name = "aspect-ratio"

    argument_names = \
        ['width', 'height']

    width: width = width
    """
    width argument of aspect_ratio.
    """
    height: height = height
    """
    height argument of aspect_ratio.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .start_time import start_time
from .stop_time import stop_time
class times(Group):
    """
    'times' child.
    """

    fluent_name = "times"

    child_names = \
        ['start_time', 'stop_time']

    start_time: start_time = start_time
    """
    start_time child of times.
    """
    stop_time: stop_time = stop_time
    """
    stop_time child of times.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .ddpm_phase import ddpm_phase
class volume_displacement(Group):
    """
    'volume_displacement' child.
    """

    fluent_name = "volume-displacement"

    child_names = \
        ['option', 'ddpm_phase']

    option: option = option
    """
    option child of volume_displacement.
    """
    ddpm_phase: ddpm_phase = ddpm_phase
    """
    ddpm_phase child of volume_displacement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .diffusion_rate_constant import diffusion_rate_constant
from .pre_exponential_factor import pre_exponential_factor
from .activation_energy import activation_energy
class kinetics_diffusion_limited(Group):
    """
    'kinetics_diffusion_limited' child.
    """

    fluent_name = "kinetics-diffusion-limited"

    child_names = \
        ['diffusion_rate_constant', 'pre_exponential_factor',
         'activation_energy']

    diffusion_rate_constant: diffusion_rate_constant = diffusion_rate_constant
    """
    diffusion_rate_constant child of kinetics_diffusion_limited.
    """
    pre_exponential_factor: pre_exponential_factor = pre_exponential_factor
    """
    pre_exponential_factor child of kinetics_diffusion_limited.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of kinetics_diffusion_limited.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class fmg_initialize(Boolean):
    """
    Initialize using the full-multigrid initialization (FMG).
    """

    fluent_name = "fmg-initialize"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .border_2 import border
from .bottom_2 import bottom
from .clear_2 import clear
from .format_1 import format
from .font_size_1 import font_size
from .left_2 import left
from .margin import margin
from .right_3 import right
from .top_2 import top
from .visible_3 import visible
class scale(Group):
    """
    Enter the color scale window options menu.
    """

    fluent_name = "scale"

    child_names = \
        ['border', 'bottom', 'clear', 'format', 'font_size', 'left', 'margin',
         'right', 'top', 'visible']

    border: border = border
    """
    border child of scale.
    """
    bottom: bottom = bottom
    """
    bottom child of scale.
    """
    clear: clear = clear
    """
    clear child of scale.
    """
    format: format = format
    """
    format child of scale.
    """
    font_size: font_size = font_size
    """
    font_size child of scale.
    """
    left: left = left
    """
    left child of scale.
    """
    margin: margin = margin
    """
    margin child of scale.
    """
    right: right = right
    """
    right child of scale.
    """
    top: top = top
    """
    top child of scale.
    """
    visible: visible = visible
    """
    visible child of scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .display import display
from .vector_child import vector_child

class vector(NamedObject[vector_child], _CreatableNamedObjectMixin[vector_child]):
    """
    'vector' child.
    """

    fluent_name = "vector"

    command_names = \
        ['display']

    display: display = display
    """
    display command of vector.
    """
    child_object_type: vector_child = vector_child
    """
    child_object_type of vector.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class film_parcel_surface_area_density(Real):
    """
    'film_parcel_surface_area_density' child.
    """

    fluent_name = "film-parcel-surface-area-density"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .solution_controls import solution_controls
from .amg_controls_1 import amg_controls
from .multi_stage_parameter import multi_stage_parameter
from .limits_1 import limits
from .reset_pseudo_time_method_generic import reset_pseudo_time_method_generic
from .reset_pseudo_time_method_equations import reset_pseudo_time_method_equations
from .reset_pseudo_time_method_relaxations import reset_pseudo_time_method_relaxations
from .reset_pseudo_time_method_scale_factors import reset_pseudo_time_method_scale_factors
class set_controls_to_default(Group):
    """
    'set_controls_to_default' child.
    """

    fluent_name = "set-controls-to-default"

    command_names = \
        ['solution_controls', 'amg_controls', 'multi_stage_parameter',
         'limits', 'reset_pseudo_time_method_generic',
         'reset_pseudo_time_method_equations',
         'reset_pseudo_time_method_relaxations',
         'reset_pseudo_time_method_scale_factors']

    solution_controls: solution_controls = solution_controls
    """
    solution_controls command of set_controls_to_default.
    """
    amg_controls: amg_controls = amg_controls
    """
    amg_controls command of set_controls_to_default.
    """
    multi_stage_parameter: multi_stage_parameter = multi_stage_parameter
    """
    multi_stage_parameter command of set_controls_to_default.
    """
    limits: limits = limits
    """
    limits command of set_controls_to_default.
    """
    reset_pseudo_time_method_generic: reset_pseudo_time_method_generic = reset_pseudo_time_method_generic
    """
    reset_pseudo_time_method_generic command of set_controls_to_default.
    """
    reset_pseudo_time_method_equations: reset_pseudo_time_method_equations = reset_pseudo_time_method_equations
    """
    reset_pseudo_time_method_equations command of set_controls_to_default.
    """
    reset_pseudo_time_method_relaxations: reset_pseudo_time_method_relaxations = reset_pseudo_time_method_relaxations
    """
    reset_pseudo_time_method_relaxations command of set_controls_to_default.
    """
    reset_pseudo_time_method_scale_factors: reset_pseudo_time_method_scale_factors = reset_pseudo_time_method_scale_factors
    """
    reset_pseudo_time_method_scale_factors command of set_controls_to_default.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .size_by import size_by
from .range import range
class variable(Group):
    """
    'variable' child.
    """

    fluent_name = "variable"

    child_names = \
        ['size_by', 'range']

    size_by: size_by = size_by
    """
    size_by child of variable.
    """
    range: range = range
    """
    range child of variable.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .read import read
from .replace_mesh import replace_mesh
from .write import write
from .parametric_project import parametric_project
class file(Group):
    """
    'file' child.
    """

    fluent_name = "file"

    command_names = \
        ['read', 'replace_mesh', 'write', 'parametric_project']

    read: read = read
    """
    read command of file.
    """
    replace_mesh: replace_mesh = replace_mesh
    """
    replace_mesh command of file.
    """
    write: write = write
    """
    write command of file.
    """
    parametric_project: parametric_project = parametric_project
    """
    parametric_project command of file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
from .surface_name_list import surface_name_list
from .structural_analysis import structural_analysis
from .write_loads import write_loads
from .loads import loads
class mechanical_apdl_input(Command):
    """
    Write an Mechanical APDL Input file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surface_name_list : typing.List[str]
            'surface_name_list' child.
        structural_analysis : bool
            'structural_analysis' child.
        write_loads : bool
            'write_loads' child.
        loads : typing.List[str]
            'loads' child.
    
    """

    fluent_name = "mechanical-apdl-input"

    argument_names = \
        ['name', 'surface_name_list', 'structural_analysis', 'write_loads',
         'loads']

    name: name = name
    """
    name argument of mechanical_apdl_input.
    """
    surface_name_list: surface_name_list = surface_name_list
    """
    surface_name_list argument of mechanical_apdl_input.
    """
    structural_analysis: structural_analysis = structural_analysis
    """
    structural_analysis argument of mechanical_apdl_input.
    """
    write_loads: write_loads = write_loads
    """
    write_loads argument of mechanical_apdl_input.
    """
    loads: loads = loads
    """
    loads argument of mechanical_apdl_input.
    """
